#!/usr/bin/perl -w
##

use strict;

use warnings;

use 5.005;

use inc::Module::Install;

require Date::Format;

require FindBin; chdir( $FindBin::Bin );

##require Getopt::Long;

##Getopt::Long::GetOptions();

##require File::Spec;

##my @tests = glob File::Spec->catfile( 't', '*.pl.t' );

##push( @tests, glob File::Spec->catfile( 't', 'use_me', '*.pl.t' ) );

my $param =
{
   'NAME' => 'Bundle-Modules',
   'CPANID' => 'ERMEYERS',
   'AUTHOR' => 'Eric R. Meyers <ermeyers@adelphia.net>',
   'VERSION' => Date::Format::time2str( '%Y.%m%d', time() ),
   'LICENSE' => 'perl',
   'ABSTRACT' => 'Interface to bundle modules',

};

name( $param->{'NAME'} );

author( $param->{'AUTHOR'} );

version( $param->{'VERSION'} );

license( $param->{'LICENSE'} );

abstract( $param->{'ABSTRACT'} );

##no##all_from( 'lib/Bundle/Modules.pm' );

unlink( "MANIFEST.bak" );

unlink( "$param->{'NAME'}-$param->{'VERSION'}.tar.gz" );

if ( -d "$FindBin::Bin/_bin" ) ## won't exist in distribution
{
   system( "$FindBin::Bin/_bin/create_bundle_modules.plx $param->{'VERSION'}" );

} ## end if

requires
(
   'perl' => '5.005',

);

feature( 'Shell.pm', '-default' => 0, recommends( 'Shell' ) ) unless can_run( 'sh' );

build_requires( 'Test::More' => 0.34 );

auto_install( 'prerequisites_policy' => 'follow' );

auto_include_deps();

sign();

WriteAll();

locate_gpg();

##
## Thanks Audrey Tang
##
END {

   print "##\n## Thanks to Mr. Audrey Tang, for being the first person to send me an encrypted email.\n##\n";

   print "Now, please enter 'Build' to make all, 'Build test' to test, and 'Build install' to install.\n";

} ## end END

##
## locate_gpg
##
sub locate_gpg
{
   print "*** Looking for GnuPG (GNU Privacy Guard, a cryptographic signature tool)...\n";

   my $gpg = can_run( 'gpg' );

   my $has_gpg = ( $gpg and `gpg --version` =~ /GnuPG/ and defined `gpg --list-public-keys` );

   if ( $has_gpg )
   {
      print "GnuPG found ($gpg).\n";

      return ( 1 ) if grep { /^--installdeps/ } @ARGV;

      if ( prompt( "Import CPAN Author $param->{'CPANID'}'s public key to GnuPG?", 'n' ) =~ /^y/i )
      {
         print 'Importing public key to GnuPG ... ';

         system 'gpg', '--quiet', '--import', glob('public_keys/'.$param->{'CPANID'}.'*.pub');

         print "done.\n";

      } ## end if

      return ( 1 );

   } ## end if

   print 'GnugPG not found anywhere in your PATH, "eek," said Mr. Audrey Tang.'."\n";

   return;

} ## end sub

##
## make a sub
##
=cut
my @missing;

my @nice = qw( Test::Pod Test::Memory::Cycle Test::Warn Test::Taint );

foreach my $nice ( @nice )
{
    eval "require $nice";

    push( @missing, $nice ) if $@;

} ## end foreach

if ( @missing )
{
    @missing = map { "\t$_\n" } @missing;

    print <<"EOT";

$param->{'NAME'}-$param->{'VERSION'} likes to have a lot of test modules for some of its tests.

The following are modules that would be nice to have, but are not required.

@missing

EOT

} ## end if
=cut

__END__
